/*
	Replication code for Autor (JEP 2015)
	Description: Cleans Census/ACS extracts downloaded from IPUMS:
	- 1980, 1990, and 2000 5% Census samples
	- Pooled 2006-2008 ACS sample
	- 2012 ACS sample

	File paths are relative to the "do" directory.

	Author: Brendan Price
	Updated July 14, 2015
*/

version 12.1
set more off
capture restore, not
pause on

foreach extract in "1980" "1990" "2000" "2006-2008" "2012" {
	if "`extract'" == "1980" | "`extract'" == "1990" | "`extract'" == "2000" | "`extract'" == "2012" {
		local y = `extract'
	}
	else if "`extract'" == "2006-2008" {
		local y = 2007
	}
	
	* Prepare the PCE deflator
	use "../dta/pce/pce-1959-2012.dta", clear
	if "`extract'" == "1980" | "`extract'" == "1990" | "`extract'" == "2000" | "`extract'" == "2012" {
		quietly sum pce if year == `extract'
	}
	else if "`extract'" == "2006-2008" {
		quietly sum pce if year == 2008
	}
	
	local pce = r(mean)

	* Load Census/ACS extract
	use "../dta/census-acs/raw/`extract'.dta", clear

	if "`extract'" == "1980" | "`extract'" == "1990" | "`extract'" == "2000" {
		keep year perwt age sex classwkrd gqtyped wkswork1 uhrswork occ occ1990 incwage
	}
	else if "`extract'" == "2006-2008" {
		keep year multyear perwt age sex gqtyped classwkrd wkswork2 uhrswork occ occ1990 incwage
	}
	else if "`extract'" == "2012" {
		keep year perwt age sex classwkrd gqtyped wkswork2 uhrswork occ occ1990 incwage
	}

	* Drop anyone with zero sampling weight
	keep if perwt > 0

	* Restrict to working-age, non-institutionalized civilian adults not employed as unpaid family workers
	keep if age >= 16 & age <= 64
	keep if gqtyped < 100 | gqtyped > 499
	keep if classwkrd != 29
	keep if occ1990 != 905
	drop gqtyped classwkrd

	/*
		Handle hours worked.
		
		Note: Computation done August 27, 2013.
		I used the 2000 extract to determine average hours worked by wkswork2 interval:
		
			gen interval = "1-13" if wkswork1 >= 1 & wkswork1 <= 13
			replace interval = "14-26" if wkswork1 >= 14 & wkswork1 <= 26
			replace interval = "27-39" if wkswork1 >= 27 & wkswork1 <= 39
			replace interval = "40-47" if wkswork1 >= 40 & wkswork1 <= 47
			replace interval = "48-49" if wkswork1 >= 48 & wkswork1 <= 49
			replace interval = "50-52" if wkswork1 >= 50 & wkswork1 <= 52		
			collapse wkswork1 [pw=perwt], by(interval)
			
		The results were as follows:
		
			1. |     1-13    7.96128 |
			2. |    14-26    21.0828 |
			3. |    27-39    32.9101 |
			4. |    40-47    42.2952 |
			5. |    48-49    48.1707 |
			6. |    50-52    51.8267 |
	*/

	if "`extract'" == "2006-2008" | "`extract'" == "2012" {
		gen wkswork1 = .
		replace wkswork1 = 0 if wkswork2 == 0
		replace wkswork1 = 7.96 if wkswork2 == 1
		replace wkswork1 = 21.08 if wkswork2 == 2
		replace wkswork1 = 32.91 if wkswork2 == 3
		replace wkswork1 = 42.30 if wkswork2 == 4
		replace wkswork1 = 48.17 if wkswork2 == 5
		replace wkswork1 = 51.83 if wkswork2 == 6
		assert wkswork1 != .
		drop wkswork2
	}
	
	/*
		Deal with topcoding: 1980 wage data are topcoded at $75,000, with no correction given.
		For subsequent extracts, topcoded incomes are given as the statewide mean of incomes above the top code.
		The correction factors used for 1990 range roughly from 1.25 to 1.4, with an employment-weighted average close to 1.4.
		I therefore multiply topcoded 1980 incomes by 1.4
	*/

	* Ensure wages are never negative
	assert incwage >= 0	

	if "`extract'" == "1980" {
		replace incwage = 0 if incwage == 999999
		assert incwage <= 75000 if incwage < .
		replace incwage = (75000 * 1.4) if incwage == 75000
	}

	* Compute each worker's labor supply weight
	gen lswt = perwt * (uhrswork/35) * (wkswork1/50)
	
	* Inflate incomes to 2012 dollars using the PCE
	replace incwage = incwage / `pce'

	* Compute hourly wage
	gen wage = incwage / (uhrswork * wkswork1) if lswt > 0 & lswt < .

	/* Map occupations into occ1990dd codes */

	if "`extract'" == "1980" | "`extract'" == "1990" | "`extract'" == "2000" {
		merge m:1 occ using "../cw/occ_occ1990dd/occ`extract'_occ1990dd.dta", keep(1 3) nogenerate
	}
	else if "`extract'" == "2006-2008" {
		replace occ = occ/10
		assert occ == floor(occ)
		merge m:1 occ using "../cw/occ_occ1990dd/occ2005_occ1990dd.dta", keep(1 3) nogenerate
	}
	else if "`extract'" == "2012" {
		merge m:1 occ using "../cw/occ_occ1990dd/occ2010_occ1990dd.dta", keep(1 3) nogenerate	
	}
	
	* Make sure that occ1990dd is populated for all workers
	assert (occ1990dd != .) & (occ1990dd != 999) if lswt > 0 & lswt < .
	drop occ occ1990
	
	* Depopulate occupation for non-workers
	replace occ1990dd = . if lswt == 0
	
	* Code the 2006-2008 sample as representing 2007
	if "`extract'" == "2006-2008" {
		replace year = 2007
	}

	* Save cleaned extract
	compress
	saveold "../dta/census-acs/clean/`y'.dta", replace
}

