/*
	Replication code for Autor (JEP 2015)
	Description: Plots employment growth in broad occupational categories from 1979-2012.
	
	Author: Brendan Price
	Updated: July 15, 2015
*/

version 12.1
set more off
clear all
capture restore, not

/* Prepare employment counts in each employment by year */

foreach y of numlist 1980 1990 2000 2007 2012 {
	use "../dta/census-acs/clean/`y'.dta", clear
	drop if occ1990dd == .
	collapse (sum) lswt, by(year occ1990dd)
	tempfile emp`y'
	saveold "`emp`y''.dta", replace
}

* Combine across years
use "`emp1980'.dta", clear
append using "`emp1990'.dta"
append using "`emp2000'.dta"
append using "`emp2007'.dta"
append using "`emp2012'.dta"

fillin year occ1990dd
replace lswt = 0 if _fillin == 1
drop _fillin

* Map occupations into broad 1-digit categories
merge m:1 occ1990dd using "../cw/occ1990dd_occ10/occ1990dd_occ10.dta", assert(3) nogenerate keepusing(occ10)

* Exclude agriculture
drop if occ10 == 40

* Recode the 1-digit occupation variable
#delimit ;
recode occ10
	(34 = 1 "Personal Care")
	(33 = 2 "Food/Cleaning Service")
	(32 = 3 "Protective Service")
	(31 = 4 "Operators/Laborers")
	(23 = 5 "Production")
	(22 = 6 "Office/Admin")
	(21 = 7 "Sales")
	(13 = 8 "Technicians")
	(12 = 9 "Professionals")
	(11 = 10 "Managers"),
gen(occ10_recode);
#delimit cr

assert occ10_recode != .
drop occ10
rename occ10_recode occ10

/* Compute changes in 1-digit occupational employment */

* Compute employment in each 1-digit occupation in each year
collapse (sum) lswt, by(year occ10)
assert lswt > 0 & lswt < .	
reshape wide lswt, i(occ10) j(year)

* Compute log changes in employment
foreach t in "1980_1990" "1990_2000" "2000_2007" "2007_2012" {
	local start = substr("`t'", 1, 4)
	local end = substr("`t'", 6, 4)
	
	gen d_emp_`t' = 100 * (log(lswt`end') - log(lswt`start'))
	label var d_emp_`t' "`start'-`end'"
}

keep occ10 d_emp_*

* Plot changes in employment growth by occupation group
#delimit ;
graph bar d_emp_*,
	over(occ10, label(labsize(small) angle(-45)))
	title("Changes in Employment by Major Occupational Category, 1979-2012", size(medium))
	ytitle("100 x Log Change in Employment")
	legend(rows(1) symxsize(*.5)
		label(1 "1979-1989")
		label(2 "1989-1999")
		label(3 "1999-2007")
		label(4 "2007-2012"))
	ylabel(-20(10)40)
	ytick(-20(10)40, grid);
#delimit cr

graph export "../out/occ10-growth/occ10-growth.eps", as(eps) replace
!epstopdf --outfile="../out/occ10-growth/occ10-growth.pdf" "../out/occ10-growth/occ10-growth.eps"
rm "../out/occ10-growth/occ10-growth.eps"

* Save the plotting points
compress
saveold "../out/occ10-growth/occ10-growth-plotting-points.dta", replace


